Network

Trait Network 

pub trait Network {
    type Addr: Ord;

    // Required methods
    fn net_start(&mut self) -> Result<(), NetworkError>;
    fn net_stop(&mut self) -> Result<(), NetworkError>;
    fn net_local_addr(&self) -> Self::Addr;
    fn net_advertise(&mut self) -> Result<(), NetworkError>;
    fn net_recv(
        &mut self,
    ) -> Result<Option<(Self::Addr, Box<[u8]>)>, NetworkError>;
    fn net_send(
        &mut self,
        addr: Self::Addr,
        data: &[u8],
    ) -> Result<(), NetworkError>;
    fn net_send_status(
        &mut self,
        addr: Self::Addr,
    ) -> Result<SendStatus, NetworkError>;
}

Required Associated Types

type Addr: Ord

The type representing the network address. Must be unique.

For emulator, it is IP+port. For the physical device, it is MAC address.

Required Methods

fn net_start(&mut self) -> Result<(), NetworkError>

Start accepting incoming network connections from other peers.

fn net_stop(&mut self) -> Result<(), NetworkError>

Stop accepting incoming network connections from other peers.

fn net_local_addr(&self) -> Self::Addr

Network address of the current device as visible to the other peers.

Used to sort all the peers, including the local one, in the same order on all devices.

fn net_advertise(&mut self) -> Result<(), NetworkError>

Broadcast device presence to all other devices nearby.

fn net_recv(&mut self) -> Result<Option<(Self::Addr, Box<[u8]>)>, NetworkError>

Get a pending message, if any. Non-blocking.

fn net_send( &mut self, addr: Self::Addr, data: &[u8], ) -> Result<(), NetworkError>

Send a raw message to the given device. Non-blocking.

fn net_send_status( &mut self, addr: Self::Addr, ) -> Result<SendStatus, NetworkError>

Send a raw message to the given device. Non-blocking.

Implementors